@@ -243,7 +243,7 @@ def outdent(value):
                 num = min(num, len(l) - len(l.lstrip()))
         return CR.join([l[num:] for l in lines])
     except Exception as e:
-        logger.error("can not outdent value", e)
+        Log.error("can not outdent value", e)
 
 
 @formatter
@@ -509,7 +509,7 @@ def limit(value, length):
             rhs = length - len(_SNIP) - lhs
             return value[:lhs] + _SNIP + value[-rhs:]
     except Exception as e:
-        logger.error("Not expected", cause=e)
+        Log.error("Not expected", cause=e)
 
 
 @formatter
@@ -625,7 +625,7 @@ def _expand(template, seq):
     elif is_list(template):
         return "".join(_expand(t, seq) for t in template)
     else:
-        logger.error("can not handle")
+        Log.error("can not handle")
 
 
 def _simple_expand(template, seq):
@@ -665,7 +665,7 @@ def _simple_expand(template, seq):
                     val = toString(val)
                     return val
             except Exception as f:
-                logger.warning(
+                Log.warning(
                     "Can not expand "
                     + "|".join(ops)
                     + " in template: {{template_|json}}",
@@ -702,14 +702,14 @@ def toString(val):
         try:
             return val.decode("latin1")
         except Exception as e:
-            logger.error(
+            Log.error(
                 text(type(val)) + " type can not be converted to unicode", cause=e
             )
     else:
         try:
             return text(val)
         except Exception as e:
-            logger.error(
+            Log.error(
                 text(type(val)) + " type can not be converted to unicode", cause=e
             )
 
@@ -786,7 +786,7 @@ def apply_diff(text, diff, reverse=False, verify=True):
     for header, hunk_body in reversed(hunks) if reverse else hunks:
         matches = DIFF_PREFIX.match(header.strip())
         if not matches:
-            logger.error("Can not handle \n---\n{{diff}}\n---\n", diff=diff)
+            Log.error("Can not handle \n---\n{{diff}}\n---\n", diff=diff)
 
         removes = tuple(
             int(i.strip()) for i in matches.group(1).split(",")
@@ -875,7 +875,7 @@ def apply_diff(text, diff, reverse=False, verify=True):
                 if t in ["reports: https://goo.gl/70o6w6\r"]:
                     break  # KNOWN INCONSISTENCIES
                 if t != o:
-                    logger.error("logical verification check failed")
+                    Log.error("logical verification check failed")
                     break
 
     return output
